<?php
namespace FeedReaderCentral;

use BitBadger\Documents\DocumentException;
use BitBadger\Documents\Field;
use BitBadger\Documents\SQLite\Document;
use BitBadger\Documents\SQLite\Find;
use SQLite3;

/**
 * A user of Feed Reader Central
 */
class User
{
    /** @var int The ID of the user */
    public int $id = 0;

    /** @var string The e-mail address for the user */
    public string $email = '';

    /** @var string The password for the user */
    public string $password = '';

    /**
     * Find a user by their e=mail address
     *
     * @param string $email The e-mail address of the user to retrieve
     * @return User|false The user information, or null if the user is not found
     * @throws DocumentException If any is encountered
     */
    public static function findByEmail(string $email): User|false
    {
        return Find::firstByFields(Table::USER, [Field::EQ('email', $email)], User::class);
    }

    /**
     * Add a user
     *
     * @param string $email The e-mail address for the user
     * @param string $password The user's password
     * @param SQLite3 $db The data connection to use to add the user
     * @throws DocumentException If any is encountered
     */
    public static function add(string $email, string $password, SQLite3 $db): void
    {
        $user           = new User();
        $user->email    = $email;
        $user->password = $password;
        Document::insert(Table::USER, $user, $db);
    }

}
