<?php

/**
 * Bookmark Partial Handler
 *
 * This will display a button which will either add or remove a bookmark for a given item.
 */

use BitBadger\Documents\DocumentException;
use BitBadger\Documents\SQLite\Find;
use BitBadger\Documents\SQLite\Patch;
use FeedReaderCentral\Data;
use FeedReaderCentral\Item;
use FeedReaderCentral\Key;
use FeedReaderCentral\Security;
use FeedReaderCentral\Table;

include '../start.php';

$db = Data::getConnection();
Security::verifyUser($db);

$id = $_GET['id'];

// TODO: adapt query once "by fields" is available
$existsQuery = $db->prepare(
    'SELECT item.id FROM item INNER JOIN feed ON feed.id = item.feed_id WHERE item.id = :id AND feed.user_id = :user');
$existsQuery->bindValue(':id',   $id);
$existsQuery->bindValue(':user', $_SESSION[Key::USER_ID]);
$existsResult = $existsQuery->execute();
$exists = $existsResult ? $existsResult->fetchArray(SQLITE3_ASSOC) : false;

if (!$exists) not_found();

if (key_exists('action', $_GET)) {
    $flag = match ($_GET['action']) {
        'add'    => 1,
        'remove' => 0,
        default  => null
    };
    if (isset($flag)) {
        try {
            Patch::byId(Table::ITEM, $id, ['is_bookmarked' => $flag], $db);
        } catch (DocumentException $ex) {
            add_error("$ex");
        }
    }
}

if (!$item = Find::byId(Table::ITEM, $id, Item::class)) not_found();

$action = $item->isBookmarked() ? 'remove' : 'add';
$icon   = $item->isBookmarked() ? 'added'  : 'add'; ?>
<button class="bookmark <?=$action?>" type=button role=button hx-patch="/bookmark?id=<?=$id?>&action=<?=$action?>"
        hx-target=this hx-swap=outerHTML hx-push-url=false title="<?=init_cap($action)?> Bookmark">
    <img src=/assets/bookmark-<?=$icon?>.png alt="<?=$action?> bookmark">
</button><?php
