<?php
/**
 * Feed Maintenance Page
 *
 * List feeds and provide links for maintenance actions
 */

use BitBadger\Documents\ArrayMapper;
use BitBadger\Documents\Field;
use BitBadger\Documents\JsonMapper;
use BitBadger\Documents\Query;
use BitBadger\Documents\SQLite\Custom;
use FeedReaderCentral\Data;
use FeedReaderCentral\Feed;
use FeedReaderCentral\Key;
use FeedReaderCentral\Security;
use FeedReaderCentral\Table;

include '../start.php';

$db = Data::getConnection();
Security::verifyUser($db);

// TODO: adapt query when document list is done
$field = Field::EQ('user_id', $_SESSION[Key::USER_ID], '@user');
$feeds = Custom::list(Query\Find::byFields(Table::FEED, [$field]) . " ORDER BY lower(data->>'title')",
    $field->toParameter(), new JsonMapper(Feed::class));

page_head('Your Feeds'); ?>
<h1>Your Feeds</h1>
<article>
    <p class=action_buttons><?=hx_get('/feed/?id=new', 'Add Feed')?></p><?php
    iterator_apply($feeds->items(), function (Feed $feed) {
        $item   = Table::ITEM;
        $counts = Custom::single(<<<SQL
            SELECT (SELECT COUNT(*) FROM $item WHERE data->>'feed_id' = @feed) AS total,
                   (SELECT COUNT(*) FROM $item WHERE data->>'feed_id' = @feed AND data->>'is_read' = '0') AS unread,
                   (SELECT COUNT(*) FROM $item WHERE data->>'feed_id' = @feed AND data->>'is_bookmarked' = '1') AS marked
            SQL, ['@feed' => $feed->id], new ArrayMapper()) ?? ['total' => 0, 'unread' => 0, 'marked' => 0]; ?>
        <p><strong><?=htmlentities($feed->title)?></strong><br>
            <span class=meta><em>Last Updated <?=date_time($feed->updated_on)?> &bull;
                As of <?=date_time($feed->checked_on)?></em><br>
                <?=hx_get("/feed/?id=$feed->id", 'Edit')?> &bull; Read
                <?=$counts['unread'] > 0 ? hx_get("/feed/items?id=$feed->id&unread", 'Unread') : 'Unread'?>
                (<?=$counts['unread']?>) |
                <?=$counts['total'] > 0 ? hx_get("/feed/items?id=$feed->id", 'All') : 'All'?> (<?=$counts['total']?>) |
                <?=$counts['marked'] > 0 ? hx_get("/feed/items?id=$feed->id&bookmarked", 'Bookmarked') : 'Bookmarked'?>
                (<?=$counts['marked']?>) &bull;
                <a href=/feed/?id=<?=$feed->id?> hx-delete=/feed/?id=<?=$feed->id?>
                   hx-confirm="Are you sure you want to delete &ldquo;<?=htmlspecialchars($feed->title)?>&rdquo;? This will remove the feed and all its items, including unread and bookmarked.">Delete</a>
            </span><?php
    }); ?>
</article><?php
page_foot();
$db->close();
