<?php

/**
 * Item View Page
 *
 * Retrieves and displays an item from a feed belonging to the current user
 */

use BitBadger\Documents\DocumentException;
use BitBadger\Documents\SQLite\Delete;
use BitBadger\Documents\SQLite\Patch;
use FeedReaderCentral\Data;
use FeedReaderCentral\Item;
use FeedReaderCentral\Key;
use FeedReaderCentral\Security;
use FeedReaderCentral\Table;

include '../start.php';

$db = Data::getConnection();
Security::verifyUser($db);

if ($_SERVER['REQUEST_METHOD'] == 'POST') {
    try {
        // "Keep as New" button sends a POST request to reset the is_read flag before going back to the item list
        if (Item::retrieveByIdForUser($_POST['id'])) {
            Patch::byId(Table::ITEM, $_POST['id'], ['is_read' => 0], $db);
        }
        $db->close();
        frc_redirect($_POST['from']);
    } catch (DocumentException $ex) {
        add_error("$ex");
    }
}

$from = $_GET['from'] ?? '/';

if ($_SERVER['REQUEST_METHOD'] == 'DELETE') {
    try {
        if (Item::retrieveByIdForUser($_GET['id'])) {
            Delete::byId(Table::ITEM, $_GET['id'], $db);
        }
    } catch (DocumentException $ex) {
        add_error("$ex");
    }
    $db->close();
    frc_redirect($from);
}

// TODO: convert this query
$query = $db->prepare(<<<'SQL'
    SELECT item.title AS item_title, item.item_link, item.published_on, item.updated_on, item.content,
           feed.title AS feed_title
      FROM item INNER JOIN feed ON feed.id = item.feed_id
     WHERE item.id      = :id
       AND feed.user_id = :user
    SQL);
$query->bindValue(':id',   $_GET['id']);
$query->bindValue(':user', $_SESSION[Key::USER_ID]);
$result = $query->execute();
$item = $result ? $result->fetchArray(SQLITE3_ASSOC) : false;

if ($item) {
    try {
        Patch::byId(Table::ITEM, $_GET['id'], ['is_read' => 1], $db);
    } catch (DocumentException $ex) {
        add_error("$ex");
    }
}

$published = date_time($item['published_on']);
$updated   = isset($item['updated_on']) ? date_time($item['updated_on']) : null;

page_head(htmlentities("{$item['item_title']} | {$item['feed_title']}")); ?>
<h1 class=item_heading>
    <span class=bookmark hx-get="/bookmark?id=<?=$_GET['id']?>" hx-trigger=load hx-target=this hx-swap=outerHTML
          hx-push-url=false></span>
    <a href="<?=$item['item_link']?>" target=_blank rel=noopener><?=strip_tags($item['item_title'])?></a><br>
</h1>
<div class=item_published>
    From <strong><?=htmlentities($item['feed_title'])?></strong><br>
    Published <?=date_time($item['published_on'])?><?=$updated && $updated != $published ? " (Updated $updated)" : ''?>
</div>
<article>
    <div class=item_content><?=str_replace('<a ', '<a target=_blank rel=noopener ', $item['content'])?></div>
    <form class=action_buttons action=/item method=POST hx-post=/item>
        <input type=hidden name=id value=<?=$_GET['id']?>>
        <input type=hidden name=from value="<?=$from?>">
        <?=hx_get($from, 'Done')?>
        <button type=submit>Keep as New</button>
        <button type=button hx-delete=/item>Delete</button>
    </form>
</article><?php
page_foot();
$db->close();
